@@ -461,6 +461,7 @@ void display_hosts(void) {
 	printf("<TH CLASS='data'>Notification Options</TH>");
 	printf("<TH CLASS='data'>Notification Period</TH>");
 	printf("<TH CLASS='data'>Event Handler</TH>");
+	printf("<TH CLASS='data'>Event Handler Period</TH>");
 	printf("<TH CLASS='data'>Enable Event Handler</TH>");
 	printf("<TH CLASS='data'>Stalking Options</TH>\n");
 	printf("<TH CLASS='data'>Enable Flap Detection</TH>");
@@ -621,6 +622,13 @@ void display_hosts(void) {
 				printf("<a href='%s?type=command&expand=%s'>%s</a></TD>\n", CONFIG_CGI, url_encode(temp_host->event_handler), html_encode(temp_host->event_handler, FALSE));
 			printf("</TD>\n");
 
+			printf("<TD CLASS='%s'>", bg_class);
+			if(temp_host->event_handler_period == NULL)
+				printf("&nbsp");
+			else
+				printf("<a href='%s?type=timeperiods&expand=%s'>%s</a>", CONFIG_CGI, url_encode(temp_host->event_handler_period), html_encode(temp_host->event_handler_period, FALSE));
+			printf("</TD>\n");
+
 			printf("<TD CLASS='%s'>", bg_class);
 			printf("%s\n", (temp_host->event_handler_enabled == TRUE) ? "Yes" : "No");
 			printf("</TD>\n");
@@ -1202,6 +1210,7 @@ void display_services(void) {
 	printf("<TH CLASS='data'>Notification Options</TH>\n");
 	printf("<TH CLASS='data'>Notification Period</TH>\n");
 	printf("<TH CLASS='data'>Event Handler</TH>");
+	printf("<TH CLASS='data'>Event Handler Period</TH>");
 	printf("<TH CLASS='data'>Enable Event Handler</TH>");
 	printf("<TH CLASS='data'>Stalking Options</TH>\n");
 	printf("<TH CLASS='data'>Enable Flap Detection</TH>");
@@ -1339,12 +1348,14 @@ void display_services(void) {
 			if(!options)
 				printf("None");
 			printf("</TD>\n");
+
 			printf("<TD CLASS='%s'>", bg_class);
 			if(temp_service->notification_period == NULL)
 				printf("&nbsp;");
 			else
 				printf("<A HREF='%s?type=timeperiods&expand=%s'>%s</A>", CONFIG_CGI, url_encode(temp_service->notification_period), html_encode(temp_service->notification_period, FALSE));
 			printf("</TD>\n");
+
 			printf("<TD CLASS='%s'>", bg_class);
 			if(temp_service->event_handler == NULL)
 				printf("&nbsp;");
@@ -1353,6 +1364,13 @@ void display_services(void) {
 				printf("<A HREF='%s?type=command&expand=%s'>%s</A>", CONFIG_CGI, url_encode(temp_service->event_handler), html_encode(temp_service->event_handler, FALSE));
 			printf("</TD>\n");
 
+			printf("<TD CLASS='%s'>", bg_class);
+			if(temp_service->event_handler_period == NULL)
+				printf("&nbsp;");
+			else
+				printf("<A HREF='%s?type=timeperiods&expand=%s'>%s</A>", CONFIG_CGI, url_encode(temp_service->event_handler_period), html_encode(temp_service->event_handler_period, FALSE));
+			printf("</TD>\n");
+
 			printf("<TD CLASS='%s'>", bg_class);
 			printf("%s\n", (temp_service->event_handler_enabled == TRUE) ? "Yes" : "No");
 			printf("</TD>\n");
@@ -2356,7 +2374,14 @@ void display_command_expansion(void) {
 							else if((*c) == '\v')	printf("[VT]");
 							else			printf("[0x%x]", *c);
 						printf("</FONT><FONT COLOR='%s'>", hash_color(i));
-						for(; c && ((*c) != '\0') && (j < (int)strlen(command_args[i]) - trail_space[i]); c++, j++) putchar(*c);
+						// Have to add some internal logic to pass the correct string to html_encode without the trailing whitespace.
+						int temp_command_length = (int)strlen(command_args[i]) - trail_space[i] - j;
+						char temp_commandline[temp_command_length+1];
+						memset(temp_commandline, 0, temp_command_length+1);
+						strncpy(temp_commandline, c, temp_command_length);
+						temp_commandline[temp_command_length] = '\0';
+						c += temp_command_length;
+						printf("%s", html_encode(temp_commandline, FALSE));
 						printf("</FONT><FONT COLOR='#0000FF'>");
 						for(; c && ((*c) != '\0'); c++)
 							/* TODO: As long as the hyperlinks change all whitespace into actual spaces,
