@@ -2,8 +2,6 @@
  *
  * NEBERRORS.H - Event broker errors
  *
- * Copyright (c) 2003-2005 Ethan Galstad (nagios@nagios.org)
- * Last Modified:   11-25-2005
  *
  * License:
  *
@@ -22,8 +20,8 @@
  *
  *****************************************************************************/
 
-#ifndef _NEBERRORS_H
-#define _NEBERRORS_H
+#ifndef NAGIOS_NEBERRORS_H_INCLUDED
+#define NAGIOS_NEBERRORS_H_INCLUDED
 
 
 /***** GENERIC DEFINES *****/
@@ -50,6 +48,8 @@
 #define NEBERROR_CALLBACKNOTFOUND   203     /* the callback could not be found */
 #define NEBERROR_NOMODULEHANDLE     204     /* no module handle specified */
 #define NEBERROR_BADMODULEHANDLE    205     /* bad module handle */
+#define NEBERROR_CALLBACKOVERRIDE   206     /* module wants to override default Nagios handling of event */
+#define NEBERROR_CALLBACKCANCEL     207     /* module wants to cancel callbacks to other modules */
 
 
 
